Struct objc2_core_image::CIBlendKernel
source · #[repr(C)]pub struct CIBlendKernel { /* private fields */ }Available on crate feature
CIKernel only.Implementations
sourceimpl CIBlendKernel
impl CIBlendKernel
pub unsafe fn kernelWithString(string: &NSString) -> Option<Retained<Self>>
👎Deprecated: Core Image Kernel Language API deprecated. (Define CI_SILENCE_GL_DEPRECATION to silence these warnings)
pub unsafe fn applyWithForeground_background( &self, foreground: &CIImage, background: &CIImage ) -> Option<Retained<CIImage>>
Available on crate feature
CIImage only.sourceimpl CIBlendKernel
impl CIBlendKernel
Methods declared on superclass CIKernel
pub unsafe fn kernelWithFunctionName_fromMetalLibraryData_error( name: &NSString, data: &NSData ) -> Result<Retained<Self>, Retained<NSError>>
pub unsafe fn kernelWithFunctionName_fromMetalLibraryData_outputPixelFormat_error( name: &NSString, data: &NSData, format: CIFormat ) -> Result<Retained<Self>, Retained<NSError>>
Available on crate feature
CIImage only.sourceimpl CIBlendKernel
impl CIBlendKernel
Methods declared on superclass NSObject
sourceimpl CIBlendKernel
impl CIBlendKernel
BuiltIn
pub unsafe fn componentAdd() -> Retained<CIBlendKernel>
pub unsafe fn componentMultiply() -> Retained<CIBlendKernel>
pub unsafe fn componentMin() -> Retained<CIBlendKernel>
pub unsafe fn componentMax() -> Retained<CIBlendKernel>
pub unsafe fn clear() -> Retained<CIBlendKernel>
pub unsafe fn source() -> Retained<CIBlendKernel>
pub unsafe fn destination() -> Retained<CIBlendKernel>
pub unsafe fn sourceOver() -> Retained<CIBlendKernel>
pub unsafe fn destinationOver() -> Retained<CIBlendKernel>
pub unsafe fn sourceIn() -> Retained<CIBlendKernel>
pub unsafe fn destinationIn() -> Retained<CIBlendKernel>
pub unsafe fn sourceOut() -> Retained<CIBlendKernel>
pub unsafe fn destinationOut() -> Retained<CIBlendKernel>
pub unsafe fn sourceAtop() -> Retained<CIBlendKernel>
pub unsafe fn destinationAtop() -> Retained<CIBlendKernel>
pub unsafe fn exclusiveOr() -> Retained<CIBlendKernel>
pub unsafe fn multiply() -> Retained<CIBlendKernel>
pub unsafe fn screen() -> Retained<CIBlendKernel>
pub unsafe fn overlay() -> Retained<CIBlendKernel>
pub unsafe fn darken() -> Retained<CIBlendKernel>
pub unsafe fn lighten() -> Retained<CIBlendKernel>
pub unsafe fn colorDodge() -> Retained<CIBlendKernel>
pub unsafe fn colorBurn() -> Retained<CIBlendKernel>
pub unsafe fn hardLight() -> Retained<CIBlendKernel>
pub unsafe fn softLight() -> Retained<CIBlendKernel>
pub unsafe fn difference() -> Retained<CIBlendKernel>
pub unsafe fn exclusion() -> Retained<CIBlendKernel>
pub unsafe fn hue() -> Retained<CIBlendKernel>
pub unsafe fn saturation() -> Retained<CIBlendKernel>
pub unsafe fn color() -> Retained<CIBlendKernel>
pub unsafe fn luminosity() -> Retained<CIBlendKernel>
pub unsafe fn subtract() -> Retained<CIBlendKernel>
pub unsafe fn divide() -> Retained<CIBlendKernel>
pub unsafe fn linearBurn() -> Retained<CIBlendKernel>
pub unsafe fn linearDodge() -> Retained<CIBlendKernel>
pub unsafe fn vividLight() -> Retained<CIBlendKernel>
pub unsafe fn linearLight() -> Retained<CIBlendKernel>
pub unsafe fn pinLight() -> Retained<CIBlendKernel>
pub unsafe fn hardMix() -> Retained<CIBlendKernel>
pub unsafe fn darkerColor() -> Retained<CIBlendKernel>
pub unsafe fn lighterColor() -> Retained<CIBlendKernel>
Methods from Deref<Target = CIColorKernel>
pub unsafe fn applyWithExtent_arguments( &self, extent: CGRect, args: Option<&NSArray<AnyObject>> ) -> Option<Retained<CIImage>>
Available on crate feature
CIImage only.Methods from Deref<Target = CIKernel>
pub unsafe fn name(&self) -> Retained<NSString>
pub unsafe fn setROISelector(&self, method: Sel)
pub unsafe fn applyWithExtent_roiCallback_arguments( &self, extent: CGRect, callback: CIKernelROICallback, args: Option<&NSArray<AnyObject>> ) -> Option<Retained<CIImage>>
Available on crate features
CIImage and block2 only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.