Struct objc2_core_image::CIContext

source ·
#[repr(C)]
pub struct CIContext { /* private fields */ }
Available on crate feature CIContext only.

Implementations

source

impl CIContext

source

pub unsafe fn contextWithOptions( options: Option<&NSDictionary<CIContextOption, AnyObject>> ) -> Retained<CIContext>

source

pub unsafe fn context() -> Retained<CIContext>

source

pub unsafe fn initWithOptions( this: Allocated<Self>, options: Option<&NSDictionary<CIContextOption, AnyObject>> ) -> Retained<Self>

source

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

source

pub unsafe fn contextWithMTLDevice( device: &ProtocolObject<dyn MTLDevice> ) -> Retained<CIContext>

Available on crate feature objc2-metal only.
source

pub unsafe fn contextWithMTLDevice_options( device: &ProtocolObject<dyn MTLDevice>, options: Option<&NSDictionary<CIContextOption, AnyObject>> ) -> Retained<CIContext>

Available on crate feature objc2-metal only.
source

pub unsafe fn contextWithMTLCommandQueue( command_queue: &ProtocolObject<dyn MTLCommandQueue> ) -> Retained<CIContext>

Available on crate feature objc2-metal only.
source

pub unsafe fn contextWithMTLCommandQueue_options( command_queue: &ProtocolObject<dyn MTLCommandQueue>, options: Option<&NSDictionary<CIContextOption, AnyObject>> ) -> Retained<CIContext>

Available on crate feature objc2-metal only.
source

pub unsafe fn workingFormat(&self) -> CIFormat

Available on crate feature CIImage only.
source

pub unsafe fn drawImage_atPoint_fromRect( &self, image: &CIImage, at_point: CGPoint, from_rect: CGRect )

👎Deprecated
Available on crate feature CIImage only.
source

pub unsafe fn drawImage_inRect_fromRect( &self, image: &CIImage, in_rect: CGRect, from_rect: CGRect )

Available on crate feature CIImage only.
source

pub unsafe fn reclaimResources(&self)

source

pub unsafe fn clearCaches(&self)

source

pub unsafe fn inputImageMaximumSize(&self) -> CGSize

source

pub unsafe fn outputImageMaximumSize(&self) -> CGSize

source

impl CIContext

Methods declared on superclass NSObject

source

pub unsafe fn new() -> Retained<Self>

source

impl CIContext

This impl block contains no items.

createCGImage

source

impl CIContext

OfflineGPUSupport

source

pub unsafe fn offlineGPUCount() -> c_uint

source

pub unsafe fn contextForOfflineGPUAtIndex( index: c_uint ) -> Option<Retained<CIContext>>

👎Deprecated: Core Image OpenGL API deprecated. (Define CI_SILENCE_GL_DEPRECATION to silence these warnings)
source

impl CIContext

ImageRepresentation

source

pub unsafe fn OpenEXRRepresentationOfImage_options_error( &self, image: &CIImage, options: &NSDictionary<CIImageRepresentationOption, AnyObject> ) -> Result<Retained<NSData>, Retained<NSError>>

Available on crate feature CIImage only.
source

pub unsafe fn writeOpenEXRRepresentationOfImage_toURL_options_error( &self, image: &CIImage, url: &NSURL, options: &NSDictionary<CIImageRepresentationOption, AnyObject> ) -> Result<(), Retained<NSError>>

Available on crate feature CIImage only.
source

impl CIContext

CIDepthBlurEffect

source

pub unsafe fn depthBlurEffectFilterForImageURL_options( &self, url: &NSURL, options: Option<&NSDictionary> ) -> Option<Retained<CIFilter>>

Available on crate feature CIFilter only.
source

pub unsafe fn depthBlurEffectFilterForImageData_options( &self, data: &NSData, options: Option<&NSDictionary> ) -> Option<Retained<CIFilter>>

Available on crate feature CIFilter only.
source

impl CIContext

CIRenderDestination

source

pub unsafe fn startTaskToRender_fromRect_toDestination_atPoint_error( &self, image: &CIImage, from_rect: CGRect, destination: &CIRenderDestination, at_point: CGPoint ) -> Result<Retained<CIRenderTask>, Retained<NSError>>

Available on crate features CIRenderDestination and CIImage only.
source

pub unsafe fn startTaskToRender_toDestination_error( &self, image: &CIImage, destination: &CIRenderDestination ) -> Result<Retained<CIRenderTask>, Retained<NSError>>

Available on crate features CIRenderDestination and CIImage only.
source

pub unsafe fn prepareRender_fromRect_toDestination_atPoint_error( &self, image: &CIImage, from_rect: CGRect, destination: &CIRenderDestination, at_point: CGPoint ) -> Result<(), Retained<NSError>>

Available on crate features CIRenderDestination and CIImage only.
source

pub unsafe fn startTaskToClear_error( &self, destination: &CIRenderDestination ) -> Result<Retained<CIRenderTask>, Retained<NSError>>

Available on crate feature CIRenderDestination only.

Methods from Deref<Target = NSObject>

source

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

source

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
source

pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

source

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.

Use Ivar::load_mut instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.