#[repr(C)]pub struct CIDataMatrixCodeDescriptor { /* private fields */ }Available on crate feature
CIBarcodeDescriptor only.Implementations
sourceimpl CIDataMatrixCodeDescriptor
impl CIDataMatrixCodeDescriptor
pub unsafe fn errorCorrectedPayload(&self) -> Retained<NSData>
pub unsafe fn rowCount(&self) -> NSInteger
pub unsafe fn columnCount(&self) -> NSInteger
pub unsafe fn eccVersion(&self) -> CIDataMatrixCodeECCVersion
pub unsafe fn initWithPayload_rowCount_columnCount_eccVersion( this: Allocated<Self>, error_corrected_payload: &NSData, row_count: NSInteger, column_count: NSInteger, ecc_version: CIDataMatrixCodeECCVersion ) -> Option<Retained<Self>>
pub unsafe fn descriptorWithPayload_rowCount_columnCount_eccVersion( error_corrected_payload: &NSData, row_count: NSInteger, column_count: NSInteger, ecc_version: CIDataMatrixCodeECCVersion ) -> Option<Retained<Self>>
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.