Struct objc2_core_image::CIFaceFeature
source · #[repr(C)]pub struct CIFaceFeature { /* private fields */ }Available on crate feature
CIFeature only.Implementations
sourceimpl CIFaceFeature
impl CIFaceFeature
pub unsafe fn bounds(&self) -> CGRect
pub unsafe fn hasLeftEyePosition(&self) -> bool
pub unsafe fn leftEyePosition(&self) -> CGPoint
pub unsafe fn hasRightEyePosition(&self) -> bool
pub unsafe fn rightEyePosition(&self) -> CGPoint
pub unsafe fn hasMouthPosition(&self) -> bool
pub unsafe fn mouthPosition(&self) -> CGPoint
pub unsafe fn hasTrackingID(&self) -> bool
pub unsafe fn trackingID(&self) -> c_int
pub unsafe fn hasTrackingFrameCount(&self) -> bool
pub unsafe fn trackingFrameCount(&self) -> c_int
pub unsafe fn hasFaceAngle(&self) -> bool
pub unsafe fn faceAngle(&self) -> c_float
pub unsafe fn hasSmile(&self) -> bool
pub unsafe fn leftEyeClosed(&self) -> bool
pub unsafe fn rightEyeClosed(&self) -> bool
Methods from Deref<Target = CIFeature>
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.