Struct objc2_core_image::CIImageAccumulator
source · #[repr(C)]pub struct CIImageAccumulator { /* private fields */ }Available on crate feature
CIImageAccumulator only.Implementations
sourceimpl CIImageAccumulator
impl CIImageAccumulator
pub unsafe fn imageAccumulatorWithExtent_format( extent: CGRect, format: CIFormat ) -> Option<Retained<Self>>
Available on crate feature
CIImage only.pub unsafe fn initWithExtent_format( this: Allocated<Self>, extent: CGRect, format: CIFormat ) -> Option<Retained<Self>>
Available on crate feature
CIImage only.pub unsafe fn extent(&self) -> CGRect
pub unsafe fn format(&self) -> CIFormat
Available on crate feature
CIImage only.pub unsafe fn image(&self) -> Retained<CIImage>
Available on crate feature
CIImage only.pub unsafe fn setImage(&self, image: &CIImage)
Available on crate feature
CIImage only.pub unsafe fn setImage_dirtyRect(&self, image: &CIImage, dirty_rect: CGRect)
Available on crate feature
CIImage only.pub unsafe fn clear(&self)
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.