Struct objc2_core_image::CIKernel
source · #[repr(C)]pub struct CIKernel { /* private fields */ }Available on crate feature
CIKernel only.Implementations
sourceimpl CIKernel
impl CIKernel
pub unsafe fn kernelsWithString( string: &NSString ) -> Option<Retained<NSArray<CIKernel>>>
👎Deprecated: Core Image Kernel Language API deprecated. (Define CI_SILENCE_GL_DEPRECATION to silence these warnings)
pub unsafe fn kernelsWithMetalString_error( source: &NSString ) -> Result<Retained<NSArray<CIKernel>>, Retained<NSError>>
pub unsafe fn kernelWithString(string: &NSString) -> Option<Retained<Self>>
👎Deprecated: Core Image Kernel Language API deprecated. (Define CI_SILENCE_GL_DEPRECATION to silence these warnings)
pub unsafe fn kernelWithFunctionName_fromMetalLibraryData_error( name: &NSString, data: &NSData ) -> Result<Retained<Self>, Retained<NSError>>
pub unsafe fn kernelWithFunctionName_fromMetalLibraryData_outputPixelFormat_error( name: &NSString, data: &NSData, format: CIFormat ) -> Result<Retained<Self>, Retained<NSError>>
Available on crate feature
CIImage only.pub unsafe fn kernelNamesFromMetalLibraryData( data: &NSData ) -> Retained<NSArray<NSString>>
pub unsafe fn name(&self) -> Retained<NSString>
pub unsafe fn setROISelector(&self, method: Sel)
pub unsafe fn applyWithExtent_roiCallback_arguments( &self, extent: CGRect, callback: CIKernelROICallback, args: Option<&NSArray<AnyObject>> ) -> Option<Retained<CIImage>>
Available on crate features
CIImage and block2 only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.