Struct objc2_core_image::CIRenderDestination
source · #[repr(C)]pub struct CIRenderDestination { /* private fields */ }Available on crate feature
CIRenderDestination only.Implementations
sourceimpl CIRenderDestination
impl CIRenderDestination
pub unsafe fn initWithMTLTexture_commandBuffer( this: Allocated<Self>, texture: &ProtocolObject<dyn MTLTexture>, command_buffer: Option<&ProtocolObject<dyn MTLCommandBuffer>> ) -> Retained<Self>
Available on crate feature
objc2-metal only.pub unsafe fn initWithWidth_height_pixelFormat_commandBuffer_mtlTextureProvider( this: Allocated<Self>, width: NSUInteger, height: NSUInteger, pixel_format: MTLPixelFormat, command_buffer: Option<&ProtocolObject<dyn MTLCommandBuffer>>, block: Option<&Block<dyn Fn() -> NonNull<ProtocolObject<dyn MTLTexture>>>> ) -> Retained<Self>
Available on crate features
block2 and objc2-metal only.pub unsafe fn initWithGLTexture_target_width_height( this: Allocated<Self>, texture: c_uint, target: c_uint, width: NSUInteger, height: NSUInteger ) -> Retained<Self>
pub unsafe fn initWithBitmapData_width_height_bytesPerRow_format( this: Allocated<Self>, data: NonNull<c_void>, width: NSUInteger, height: NSUInteger, bytes_per_row: NSUInteger, format: CIFormat ) -> Retained<Self>
Available on crate feature
CIImage only.pub unsafe fn width(&self) -> NSUInteger
pub unsafe fn height(&self) -> NSUInteger
pub unsafe fn alphaMode(&self) -> CIRenderDestinationAlphaMode
pub unsafe fn setAlphaMode(&self, alpha_mode: CIRenderDestinationAlphaMode)
pub unsafe fn isFlipped(&self) -> bool
pub unsafe fn setFlipped(&self, flipped: bool)
pub unsafe fn isDithered(&self) -> bool
pub unsafe fn setDithered(&self, dithered: bool)
pub unsafe fn isClamped(&self) -> bool
pub unsafe fn setClamped(&self, clamped: bool)
pub unsafe fn blendKernel(&self) -> Option<Retained<CIBlendKernel>>
Available on crate feature
CIKernel only.pub unsafe fn setBlendKernel(&self, blend_kernel: Option<&CIBlendKernel>)
Available on crate feature
CIKernel only.pub unsafe fn blendsInDestinationColorSpace(&self) -> bool
pub unsafe fn setBlendsInDestinationColorSpace( &self, blends_in_destination_color_space: bool )
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.