Struct objc2_core_image::CIVector
source · #[repr(C)]pub struct CIVector { /* private fields */ }Available on crate feature
CIVector only.Implementations
sourceimpl CIVector
impl CIVector
pub unsafe fn vectorWithValues_count( values: NonNull<CGFloat>, count: usize ) -> Retained<Self>
pub unsafe fn vectorWithX(x: CGFloat) -> Retained<Self>
pub unsafe fn vectorWithX_Y(x: CGFloat, y: CGFloat) -> Retained<Self>
pub unsafe fn vectorWithX_Y_Z( x: CGFloat, y: CGFloat, z: CGFloat ) -> Retained<Self>
pub unsafe fn vectorWithX_Y_Z_W( x: CGFloat, y: CGFloat, z: CGFloat, w: CGFloat ) -> Retained<Self>
pub unsafe fn vectorWithCGPoint(p: CGPoint) -> Retained<Self>
pub unsafe fn vectorWithCGRect(r: CGRect) -> Retained<Self>
pub unsafe fn vectorWithString(representation: &NSString) -> Retained<Self>
pub unsafe fn initWithValues_count( this: Allocated<Self>, values: NonNull<CGFloat>, count: usize ) -> Retained<Self>
pub unsafe fn initWithX(this: Allocated<Self>, x: CGFloat) -> Retained<Self>
pub unsafe fn initWithX_Y( this: Allocated<Self>, x: CGFloat, y: CGFloat ) -> Retained<Self>
pub unsafe fn initWithX_Y_Z( this: Allocated<Self>, x: CGFloat, y: CGFloat, z: CGFloat ) -> Retained<Self>
pub unsafe fn initWithX_Y_Z_W( this: Allocated<Self>, x: CGFloat, y: CGFloat, z: CGFloat, w: CGFloat ) -> Retained<Self>
pub unsafe fn initWithCGPoint( this: Allocated<Self>, p: CGPoint ) -> Retained<Self>
pub unsafe fn initWithCGRect(this: Allocated<Self>, r: CGRect) -> Retained<Self>
pub unsafe fn initWithString( this: Allocated<Self>, representation: &NSString ) -> Retained<Self>
pub unsafe fn valueAtIndex(&self, index: usize) -> CGFloat
pub unsafe fn count(&self) -> usize
pub unsafe fn X(&self) -> CGFloat
pub unsafe fn Y(&self) -> CGFloat
pub unsafe fn Z(&self) -> CGFloat
pub unsafe fn W(&self) -> CGFloat
pub unsafe fn CGPointValue(&self) -> CGPoint
pub unsafe fn CGRectValue(&self) -> CGRect
pub unsafe fn stringRepresentation(&self) -> Retained<NSString>
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.