Struct objc2_core_image::CIContext
source · #[repr(C)]pub struct CIContext { /* private fields */ }Available on crate feature
CIContext only.Implementations
sourceimpl CIContext
impl CIContext
pub unsafe fn contextWithOptions( options: Option<&NSDictionary<CIContextOption, AnyObject>> ) -> Retained<CIContext>
pub unsafe fn context() -> Retained<CIContext>
pub unsafe fn initWithOptions( this: Allocated<Self>, options: Option<&NSDictionary<CIContextOption, AnyObject>> ) -> Retained<Self>
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn contextWithMTLDevice( device: &ProtocolObject<dyn MTLDevice> ) -> Retained<CIContext>
Available on crate feature
objc2-metal only.pub unsafe fn contextWithMTLDevice_options( device: &ProtocolObject<dyn MTLDevice>, options: Option<&NSDictionary<CIContextOption, AnyObject>> ) -> Retained<CIContext>
Available on crate feature
objc2-metal only.pub unsafe fn contextWithMTLCommandQueue( command_queue: &ProtocolObject<dyn MTLCommandQueue> ) -> Retained<CIContext>
Available on crate feature
objc2-metal only.pub unsafe fn contextWithMTLCommandQueue_options( command_queue: &ProtocolObject<dyn MTLCommandQueue>, options: Option<&NSDictionary<CIContextOption, AnyObject>> ) -> Retained<CIContext>
Available on crate feature
objc2-metal only.pub unsafe fn workingFormat(&self) -> CIFormat
Available on crate feature
CIImage only.pub unsafe fn drawImage_atPoint_fromRect( &self, image: &CIImage, at_point: CGPoint, from_rect: CGRect )
👎Deprecated
Available on crate feature
CIImage only.pub unsafe fn drawImage_inRect_fromRect( &self, image: &CIImage, in_rect: CGRect, from_rect: CGRect )
Available on crate feature
CIImage only.pub unsafe fn reclaimResources(&self)
pub unsafe fn clearCaches(&self)
pub unsafe fn inputImageMaximumSize(&self) -> CGSize
pub unsafe fn outputImageMaximumSize(&self) -> CGSize
impl CIContext
This impl block contains no items.
createCGImage
sourceimpl CIContext
impl CIContext
OfflineGPUSupport
pub unsafe fn offlineGPUCount() -> c_uint
pub unsafe fn contextForOfflineGPUAtIndex( index: c_uint ) -> Option<Retained<CIContext>>
👎Deprecated: Core Image OpenGL API deprecated. (Define CI_SILENCE_GL_DEPRECATION to silence these warnings)
sourceimpl CIContext
impl CIContext
ImageRepresentation
pub unsafe fn OpenEXRRepresentationOfImage_options_error( &self, image: &CIImage, options: &NSDictionary<CIImageRepresentationOption, AnyObject> ) -> Result<Retained<NSData>, Retained<NSError>>
Available on crate feature
CIImage only.pub unsafe fn writeOpenEXRRepresentationOfImage_toURL_options_error( &self, image: &CIImage, url: &NSURL, options: &NSDictionary<CIImageRepresentationOption, AnyObject> ) -> Result<(), Retained<NSError>>
Available on crate feature
CIImage only.sourceimpl CIContext
impl CIContext
CIDepthBlurEffect
pub unsafe fn depthBlurEffectFilterForImageURL_options( &self, url: &NSURL, options: Option<&NSDictionary> ) -> Option<Retained<CIFilter>>
Available on crate feature
CIFilter only.pub unsafe fn depthBlurEffectFilterForImageData_options( &self, data: &NSData, options: Option<&NSDictionary> ) -> Option<Retained<CIFilter>>
Available on crate feature
CIFilter only.sourceimpl CIContext
impl CIContext
CIRenderDestination
pub unsafe fn startTaskToRender_fromRect_toDestination_atPoint_error( &self, image: &CIImage, from_rect: CGRect, destination: &CIRenderDestination, at_point: CGPoint ) -> Result<Retained<CIRenderTask>, Retained<NSError>>
Available on crate features
CIRenderDestination and CIImage only.pub unsafe fn startTaskToRender_toDestination_error( &self, image: &CIImage, destination: &CIRenderDestination ) -> Result<Retained<CIRenderTask>, Retained<NSError>>
Available on crate features
CIRenderDestination and CIImage only.pub unsafe fn prepareRender_fromRect_toDestination_atPoint_error( &self, image: &CIImage, from_rect: CGRect, destination: &CIRenderDestination, at_point: CGPoint ) -> Result<(), Retained<NSError>>
Available on crate features
CIRenderDestination and CIImage only.pub unsafe fn startTaskToClear_error( &self, destination: &CIRenderDestination ) -> Result<Retained<CIRenderTask>, Retained<NSError>>
Available on crate feature
CIRenderDestination only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.