Struct objc2_core_image::CIImage

source ·
#[repr(C)]
pub struct CIImage { /* private fields */ }
Available on crate feature CIImage only.

Implementations

source

impl CIImage

source

pub unsafe fn imageWithTexture_size_flipped_options( name: c_uint, size: CGSize, flipped: bool, options: Option<&NSDictionary<CIImageOption, AnyObject>> ) -> Retained<CIImage>

👎Deprecated: Core Image OpenGL API deprecated. (Define CI_SILENCE_GL_DEPRECATION to silence these warnings)
source

pub unsafe fn imageWithMTLTexture_options( texture: &ProtocolObject<dyn MTLTexture>, options: Option<&NSDictionary<CIImageOption, AnyObject>> ) -> Option<Retained<CIImage>>

Available on crate feature objc2-metal only.
source

pub unsafe fn imageWithContentsOfURL(url: &NSURL) -> Option<Retained<CIImage>>

source

pub unsafe fn imageWithContentsOfURL_options( url: &NSURL, options: Option<&NSDictionary<CIImageOption, AnyObject>> ) -> Option<Retained<CIImage>>

source

pub unsafe fn imageWithData(data: &NSData) -> Option<Retained<CIImage>>

source

pub unsafe fn imageWithData_options( data: &NSData, options: Option<&NSDictionary<CIImageOption, AnyObject>> ) -> Option<Retained<CIImage>>

source

pub unsafe fn imageWithColor(color: &CIColor) -> Retained<CIImage>

Available on crate feature CIColor only.
source

pub unsafe fn emptyImage() -> Retained<CIImage>

source

pub unsafe fn blackImage() -> Retained<CIImage>

source

pub unsafe fn whiteImage() -> Retained<CIImage>

source

pub unsafe fn grayImage() -> Retained<CIImage>

source

pub unsafe fn redImage() -> Retained<CIImage>

source

pub unsafe fn greenImage() -> Retained<CIImage>

source

pub unsafe fn blueImage() -> Retained<CIImage>

source

pub unsafe fn cyanImage() -> Retained<CIImage>

source

pub unsafe fn magentaImage() -> Retained<CIImage>

source

pub unsafe fn yellowImage() -> Retained<CIImage>

source

pub unsafe fn clearImage() -> Retained<CIImage>

source

pub unsafe fn initWithData( this: Allocated<Self>, data: &NSData ) -> Option<Retained<Self>>

source

pub unsafe fn initWithData_options( this: Allocated<Self>, data: &NSData, options: Option<&NSDictionary<CIImageOption, AnyObject>> ) -> Option<Retained<Self>>

source

pub unsafe fn initWithTexture_size_flipped_options( this: Allocated<Self>, name: c_uint, size: CGSize, flipped: bool, options: Option<&NSDictionary<CIImageOption, AnyObject>> ) -> Retained<Self>

👎Deprecated: Core Image OpenGL API deprecated. (Define CI_SILENCE_GL_DEPRECATION to silence these warnings)
source

pub unsafe fn initWithMTLTexture_options( this: Allocated<Self>, texture: &ProtocolObject<dyn MTLTexture>, options: Option<&NSDictionary<CIImageOption, AnyObject>> ) -> Option<Retained<Self>>

Available on crate feature objc2-metal only.
source

pub unsafe fn initWithContentsOfURL( this: Allocated<Self>, url: &NSURL ) -> Option<Retained<Self>>

source

pub unsafe fn initWithContentsOfURL_options( this: Allocated<Self>, url: &NSURL, options: Option<&NSDictionary<CIImageOption, AnyObject>> ) -> Option<Retained<Self>>

source

pub unsafe fn initWithColor( this: Allocated<Self>, color: &CIColor ) -> Retained<Self>

Available on crate feature CIColor only.
source

pub unsafe fn imageByApplyingOrientation( &self, orientation: c_int ) -> Retained<CIImage>

source

pub unsafe fn imageByCompositingOverImage( &self, dest: &CIImage ) -> Retained<CIImage>

source

pub unsafe fn imageByCroppingToRect(&self, rect: CGRect) -> Retained<CIImage>

source

pub unsafe fn imageByClampingToExtent(&self) -> Retained<CIImage>

source

pub unsafe fn imageByClampingToRect(&self, rect: CGRect) -> Retained<CIImage>

source

pub unsafe fn imageByApplyingFilter_withInputParameters( &self, filter_name: &NSString, params: Option<&NSDictionary<NSString, AnyObject>> ) -> Retained<CIImage>

source

pub unsafe fn imageByApplyingFilter( &self, filter_name: &NSString ) -> Retained<CIImage>

source

pub unsafe fn imageByPremultiplyingAlpha(&self) -> Retained<CIImage>

source

pub unsafe fn imageByUnpremultiplyingAlpha(&self) -> Retained<CIImage>

source

pub unsafe fn imageBySettingAlphaOneInExtent( &self, extent: CGRect ) -> Retained<CIImage>

source

pub unsafe fn imageByApplyingGaussianBlurWithSigma( &self, sigma: c_double ) -> Retained<CIImage>

source

pub unsafe fn imageBySettingProperties( &self, properties: &NSDictionary ) -> Retained<CIImage>

source

pub unsafe fn imageBySamplingLinear(&self) -> Retained<CIImage>

source

pub unsafe fn imageBySamplingNearest(&self) -> Retained<CIImage>

source

pub unsafe fn imageByInsertingIntermediate(&self) -> Retained<CIImage>

source

pub unsafe fn imageByInsertingIntermediate_( &self, cache: bool ) -> Retained<CIImage>

source

pub unsafe fn extent(&self) -> CGRect

source

pub unsafe fn properties(&self) -> Retained<NSDictionary<NSString, AnyObject>>

source

pub unsafe fn definition(&self) -> Retained<CIFilterShape>

Available on crate feature CIFilterShape only.
source

pub unsafe fn url(&self) -> Option<Retained<NSURL>>

source

pub unsafe fn regionOfInterestForImage_inRect( &self, image: &CIImage, rect: CGRect ) -> CGRect

source

impl CIImage

Methods declared on superclass NSObject

source

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

source

pub unsafe fn new() -> Retained<Self>

source

impl CIImage

AutoAdjustment

source

pub unsafe fn autoAdjustmentFilters(&self) -> Retained<NSArray<CIFilter>>

Available on crate feature CIFilter only.
source

pub unsafe fn autoAdjustmentFiltersWithOptions( &self, options: Option<&NSDictionary<CIImageAutoAdjustmentOption, AnyObject>> ) -> Retained<NSArray<CIFilter>>

Available on crate feature CIFilter only.
source

impl CIImage

LabConversion

source

impl CIImage

This impl block contains no items.

CIImageProvider

Methods from Deref<Target = NSObject>

source

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

source

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
source

pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

source

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.

Use Ivar::load_mut instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.