Struct objc2_core_image::CIImage
source · #[repr(C)]pub struct CIImage { /* private fields */ }Available on crate feature
CIImage only.Implementations
sourceimpl CIImage
impl CIImage
pub unsafe fn imageWithTexture_size_flipped_options( name: c_uint, size: CGSize, flipped: bool, options: Option<&NSDictionary<CIImageOption, AnyObject>> ) -> Retained<CIImage>
👎Deprecated: Core Image OpenGL API deprecated. (Define CI_SILENCE_GL_DEPRECATION to silence these warnings)
pub unsafe fn imageWithMTLTexture_options( texture: &ProtocolObject<dyn MTLTexture>, options: Option<&NSDictionary<CIImageOption, AnyObject>> ) -> Option<Retained<CIImage>>
Available on crate feature
objc2-metal only.pub unsafe fn imageWithContentsOfURL(url: &NSURL) -> Option<Retained<CIImage>>
pub unsafe fn imageWithContentsOfURL_options( url: &NSURL, options: Option<&NSDictionary<CIImageOption, AnyObject>> ) -> Option<Retained<CIImage>>
pub unsafe fn imageWithData(data: &NSData) -> Option<Retained<CIImage>>
pub unsafe fn imageWithData_options( data: &NSData, options: Option<&NSDictionary<CIImageOption, AnyObject>> ) -> Option<Retained<CIImage>>
pub unsafe fn imageWithColor(color: &CIColor) -> Retained<CIImage>
Available on crate feature
CIColor only.pub unsafe fn emptyImage() -> Retained<CIImage>
pub unsafe fn blackImage() -> Retained<CIImage>
pub unsafe fn whiteImage() -> Retained<CIImage>
pub unsafe fn grayImage() -> Retained<CIImage>
pub unsafe fn redImage() -> Retained<CIImage>
pub unsafe fn greenImage() -> Retained<CIImage>
pub unsafe fn blueImage() -> Retained<CIImage>
pub unsafe fn cyanImage() -> Retained<CIImage>
pub unsafe fn magentaImage() -> Retained<CIImage>
pub unsafe fn yellowImage() -> Retained<CIImage>
pub unsafe fn clearImage() -> Retained<CIImage>
pub unsafe fn initWithData( this: Allocated<Self>, data: &NSData ) -> Option<Retained<Self>>
pub unsafe fn initWithData_options( this: Allocated<Self>, data: &NSData, options: Option<&NSDictionary<CIImageOption, AnyObject>> ) -> Option<Retained<Self>>
pub unsafe fn initWithTexture_size_flipped_options( this: Allocated<Self>, name: c_uint, size: CGSize, flipped: bool, options: Option<&NSDictionary<CIImageOption, AnyObject>> ) -> Retained<Self>
👎Deprecated: Core Image OpenGL API deprecated. (Define CI_SILENCE_GL_DEPRECATION to silence these warnings)
pub unsafe fn initWithMTLTexture_options( this: Allocated<Self>, texture: &ProtocolObject<dyn MTLTexture>, options: Option<&NSDictionary<CIImageOption, AnyObject>> ) -> Option<Retained<Self>>
Available on crate feature
objc2-metal only.pub unsafe fn initWithContentsOfURL( this: Allocated<Self>, url: &NSURL ) -> Option<Retained<Self>>
pub unsafe fn initWithContentsOfURL_options( this: Allocated<Self>, url: &NSURL, options: Option<&NSDictionary<CIImageOption, AnyObject>> ) -> Option<Retained<Self>>
pub unsafe fn initWithColor( this: Allocated<Self>, color: &CIColor ) -> Retained<Self>
Available on crate feature
CIColor only.pub unsafe fn imageByApplyingOrientation( &self, orientation: c_int ) -> Retained<CIImage>
pub unsafe fn imageByCompositingOverImage( &self, dest: &CIImage ) -> Retained<CIImage>
pub unsafe fn imageByCroppingToRect(&self, rect: CGRect) -> Retained<CIImage>
pub unsafe fn imageByClampingToExtent(&self) -> Retained<CIImage>
pub unsafe fn imageByClampingToRect(&self, rect: CGRect) -> Retained<CIImage>
pub unsafe fn imageByApplyingFilter_withInputParameters( &self, filter_name: &NSString, params: Option<&NSDictionary<NSString, AnyObject>> ) -> Retained<CIImage>
pub unsafe fn imageByApplyingFilter( &self, filter_name: &NSString ) -> Retained<CIImage>
pub unsafe fn imageByPremultiplyingAlpha(&self) -> Retained<CIImage>
pub unsafe fn imageByUnpremultiplyingAlpha(&self) -> Retained<CIImage>
pub unsafe fn imageBySettingAlphaOneInExtent( &self, extent: CGRect ) -> Retained<CIImage>
pub unsafe fn imageByApplyingGaussianBlurWithSigma( &self, sigma: c_double ) -> Retained<CIImage>
pub unsafe fn imageBySettingProperties( &self, properties: &NSDictionary ) -> Retained<CIImage>
pub unsafe fn imageBySamplingLinear(&self) -> Retained<CIImage>
pub unsafe fn imageBySamplingNearest(&self) -> Retained<CIImage>
pub unsafe fn imageByInsertingIntermediate(&self) -> Retained<CIImage>
pub unsafe fn imageByInsertingIntermediate_( &self, cache: bool ) -> Retained<CIImage>
pub unsafe fn extent(&self) -> CGRect
pub unsafe fn properties(&self) -> Retained<NSDictionary<NSString, AnyObject>>
pub unsafe fn definition(&self) -> Retained<CIFilterShape>
Available on crate feature
CIFilterShape only.pub unsafe fn url(&self) -> Option<Retained<NSURL>>
pub unsafe fn regionOfInterestForImage_inRect( &self, image: &CIImage, rect: CGRect ) -> CGRect
sourceimpl CIImage
impl CIImage
AutoAdjustment
pub unsafe fn autoAdjustmentFilters(&self) -> Retained<NSArray<CIFilter>>
Available on crate feature
CIFilter only.pub unsafe fn autoAdjustmentFiltersWithOptions( &self, options: Option<&NSDictionary<CIImageAutoAdjustmentOption, AnyObject>> ) -> Retained<NSArray<CIFilter>>
Available on crate feature
CIFilter only.sourceimpl CIImage
impl CIImage
LabConversion
pub unsafe fn imageByConvertingWorkingSpaceToLab(&self) -> Retained<CIImage>
pub unsafe fn imageByConvertingLabToWorkingSpace(&self) -> Retained<CIImage>
impl CIImage
This impl block contains no items.
CIImageProvider
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.